<div class="container">
    <Button class="btn btn-default" (click)="mainClicked()">Back to Main</Button>

<!--    <table class="table table-striped">-->
<!--        <thead>-->
<!--        <tr>-->
<!--            <th>String</th>-->
<!--            <th>Int</th>-->
<!--            <th></th>-->
<!--        </tr>-->
<!--        </thead>-->
<!--        <tbody>-->
<!--        <tr *ngFor="let item of branchDetails">-->
<!--            <td>{{item.string1}}</td>-->
<!--            <td>{{item.int1}}</td>-->
<!--            <td>-->
<!--                <Button class="btn btn-default" (click)="toggleUpperCicked(item)">-->
<!--                    Toggle Caps-->
<!--                </Button>-->
<!--                <Button class="btn btn-default" (click)="incrementCicked(item)">-->
<!--                    Increment Int-->
<!--                </Button>-->
<!--                <Button class="btn btn-default" (click)="decrementCicked(item)">-->
<!--                    Decrement Int-->
<!--                </Button>-->
<!--            </td>-->
<!--        </tr>-->
<!--        </tbody>-->
<!--    </table>-->
</div>